@@ -56,8 +56,8 @@ static size_t WriteCallback(void *ptr, size_t size, size_t nmemb, void *data)
 {
   /* we are not interested in the downloaded bytes itself,
      so we only return the size we would have saved ... */
-  (void)ptr;  /* unused */
-  (void)data; /* unused */
+  (void)ptr;
+  (void)data;
   return (size_t)(size * nmemb);
 }
 
@@ -79,12 +79,12 @@ int main(int argc, char *argv[])
           fprintf(stderr,
                   "\rUsage: %s [-m=1|2|5|10|20|50|100] [-t] [-x] [url]\n",
                   appname);
-          exit(1);
+          return 1;
         case 'v':
         case 'V':
           fprintf(stderr, "\r%s %s - %s\n",
                   appname, CHKSPEED_VERSION, curl_version());
-          exit(1);
+          return 1;
         case 'a':
         case 'A':
           prtall = 1;
@@ -100,7 +100,7 @@ int main(int argc, char *argv[])
         case 'm':
         case 'M':
           if(argv[0][2] == '=') {
-            long m = strtol((*argv) + 3, NULL, 10);
+            int m = atoi((*argv) + 3);
             switch(m) {
             case 1:
               url = URL_1M;
@@ -156,66 +156,73 @@ int main(int argc, char *argv[])
   }
 
   /* init libcurl */
-  curl_global_init(CURL_GLOBAL_ALL);
+  res = curl_global_init(CURL_GLOBAL_ALL);
+  if(res)
+    return (int)res;
 
   /* init the curl session */
   curl_handle = curl_easy_init();
+  if(curl_handle) {
 
-  /* specify URL to get */
-  curl_easy_setopt(curl_handle, CURLOPT_URL, url);
+    /* specify URL to get */
+    curl_easy_setopt(curl_handle, CURLOPT_URL, url);
 
-  /* send all data to this function  */
-  curl_easy_setopt(curl_handle, CURLOPT_WRITEFUNCTION, WriteCallback);
+    /* send all data to this function  */
+    curl_easy_setopt(curl_handle, CURLOPT_WRITEFUNCTION, WriteCallback);
 
-  /* some servers do not like requests that are made without a user-agent
-     field, so we provide one */
-  curl_easy_setopt(curl_handle, CURLOPT_USERAGENT,
-                   "libcurl-speedchecker/" CHKSPEED_VERSION);
+    /* some servers do not like requests that are made without a user-agent
+       field, so we provide one */
+    curl_easy_setopt(curl_handle, CURLOPT_USERAGENT,
+                     "libcurl-speedchecker/" CHKSPEED_VERSION);
 
-  /* get it! */
-  res = curl_easy_perform(curl_handle);
+    /* get it! */
+    res = curl_easy_perform(curl_handle);
 
-  if(CURLE_OK == res) {
-    curl_off_t val;
+    if(CURLE_OK == res) {
+      curl_off_t val;
 
-    /* check for bytes downloaded */
-    res = curl_easy_getinfo(curl_handle, CURLINFO_SIZE_DOWNLOAD_T, &val);
-    if((CURLE_OK == res) && (val>0))
-      printf("Data downloaded: %lu bytes.\n", (unsigned long)val);
+      /* check for bytes downloaded */
+      res = curl_easy_getinfo(curl_handle, CURLINFO_SIZE_DOWNLOAD_T, &val);
+      if((CURLE_OK == res) && (val > 0))
+        printf("Data downloaded: %lu bytes.\n", (unsigned long)val);
 
-    /* check for total download time */
-    res = curl_easy_getinfo(curl_handle, CURLINFO_TOTAL_TIME_T, &val);
-    if((CURLE_OK == res) && (val>0))
-      printf("Total download time: %lu.%06lu sec.\n",
-             (unsigned long)(val / 1000000), (unsigned long)(val % 1000000));
+      /* check for total download time */
+      res = curl_easy_getinfo(curl_handle, CURLINFO_TOTAL_TIME_T, &val);
+      if((CURLE_OK == res) && (val > 0))
+        printf("Total download time: %lu.%06lu sec.\n",
+               (unsigned long)(val / 1000000),
+               (unsigned long)(val % 1000000));
 
-    /* check for average download speed */
-    res = curl_easy_getinfo(curl_handle, CURLINFO_SPEED_DOWNLOAD_T, &val);
-    if((CURLE_OK == res) && (val>0))
-      printf("Average download speed: %lu kbyte/sec.\n",
-             (unsigned long)(val / 1024));
+      /* check for average download speed */
+      res = curl_easy_getinfo(curl_handle, CURLINFO_SPEED_DOWNLOAD_T, &val);
+      if((CURLE_OK == res) && (val > 0))
+        printf("Average download speed: %lu kbyte/sec.\n",
+               (unsigned long)(val / 1024));
 
-    if(prtall) {
-      /* check for name resolution time */
-      res = curl_easy_getinfo(curl_handle, CURLINFO_NAMELOOKUP_TIME_T, &val);
-      if((CURLE_OK == res) && (val>0))
-        printf("Name lookup time: %lu.%06lu sec.\n",
-               (unsigned long)(val / 1000000), (unsigned long)(val % 1000000));
+      if(prtall) {
+        /* check for name resolution time */
+        res = curl_easy_getinfo(curl_handle, CURLINFO_NAMELOOKUP_TIME_T, &val);
+        if((CURLE_OK == res) && (val > 0))
+          printf("Name lookup time: %lu.%06lu sec.\n",
+                 (unsigned long)(val / 1000000),
+                 (unsigned long)(val % 1000000));
 
-      /* check for connect time */
-      res = curl_easy_getinfo(curl_handle, CURLINFO_CONNECT_TIME_T, &val);
-      if((CURLE_OK == res) && (val>0))
-        printf("Connect time: %lu.%06lu sec.\n",
-               (unsigned long)(val / 1000000), (unsigned long)(val % 1000000));
+        /* check for connect time */
+        res = curl_easy_getinfo(curl_handle, CURLINFO_CONNECT_TIME_T, &val);
+        if((CURLE_OK == res) && (val > 0))
+          printf("Connect time: %lu.%06lu sec.\n",
+                 (unsigned long)(val / 1000000),
+                 (unsigned long)(val % 1000000));
+      }
+    }
+    else {
+      fprintf(stderr, "Error while fetching '%s' : %s\n",
+              url, curl_easy_strerror(res));
     }
-  }
-  else {
-    fprintf(stderr, "Error while fetching '%s' : %s\n",
-            url, curl_easy_strerror(res));
-  }
 
-  /* cleanup curl stuff */
-  curl_easy_cleanup(curl_handle);
+    /* cleanup curl stuff */
+    curl_easy_cleanup(curl_handle);
+  }
 
   /* we are done with libcurl, so clean it up */
   curl_global_cleanup();
